@@ -1,9 +1,11 @@
 from typing import List, Optional
+from .utils import Util
 
 
 class ClassDomain:
     DEF = "class_domain"
 
+
     def __init__(self, name, parent_domain=None):
         self._parent_domain = parent_domain
         self._name = name
@@ -53,6 +55,11 @@ class ClassDomain:
             return True
         return False
 
+    def __eq__(self, other):
+        self._sort_label()
+        other._sort_label()
+        return self._classes_names == other._classes_names
+
     def format(self):
         domain_name = self.name
         if self.parent_domain:
@@ -62,6 +69,13 @@ class ClassDomain:
         self._sort_label()
         classes = [_.format() for _ in self._classes]
         content["classes"] = classes
+
+        if "skeleton" in self._attributes:
+            skeleton = []
+            for _s in self._attributes["skeleton"]:
+                skeleton.append(Util.flist(_s))
+            content["skeleton"] = skeleton
+
         return {domain_name: content}
 
 
