@@ -29,11 +29,28 @@ class DataSample:
 
         return sample
 
+    def set_domain(self, domain):
+        if not isinstance(domain, list):
+            self.class_domain = [domain]
+        else:
+            self.class_domain = domain
+
     @property
     def sample_type(self):
-        return f"{self.sample_struct.name}[{self.sample_struct.ARG}={self.class_domain.name}]"
+        ARG = self.sample_struct.args
+        if not ARG:
+            return self.sample_struct.name
+        if not isinstance(ARG, list):
+            ARG = [ARG]
+        class_domain = self.class_domain
+        if not isinstance(self.class_domain, list):
+            class_domain = [class_domain]
+        class_domain_name = [_.name for _ in class_domain]
+        assert len(ARG) == len(class_domain_name), "argument and value not match"
+        string = ', '.join(["=".join(item) for item in zip(ARG, class_domain_name)])
+        return f"{self.sample_struct.name}[{string}]"
 
-    def format(self, file_name="local"):
+    def format(self, file_name="$local"):
         content = dict()
         content["sample-type"] = self.sample_type
         content["sample-path"] = file_name
